fars_map_state: Plots the acidents on a map for a user specified year and...

Description Usage Arguments Value Examples

View source: R/fars_funtions.R

Description

User specifies year and state (as function parameters) and the function will plot the acidents for that given year, on a map of the state Acidents will be ploted has dots, based on their latitude and longitude

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

interger specifying the state

year

interger specifying the year of data to be ploted

Value

The function plots the acidents for a given year on a map of the state

Examples

1
2
3
4
## Not run: 
fars_map_state (45,2014)

## End(Not run)

joaojcorreia/FarsR documentation built on Feb. 18, 2020, 12:30 a.m.