fars_read: Reading data from file Funtions reads data from Fatality...

Description Usage Arguments Value Examples

View source: R/fars_funtions.R

Description

Reading data from file Funtions reads data from Fatality Analysis Reporting System The function will read the defined data file into data table. If the data file is not available it will give an error message

Usage

1
fars_read(filename)

Arguments

filename

string indicating the data name

Value

The function will read the file extablishe in the function parameter, and loads it in to a data table If file does not exist, the function will return an error message.

Examples

1
2
3
4
## Not run: 
fars_read("accident_2013.csv.bz")

## End(Not run)

joaojcorreia/FarsR documentation built on Feb. 18, 2020, 12:30 a.m.