fars_read_years: Reads several years of data from the data set

Description Usage Arguments Value Examples

View source: R/fars_funtions.R

Description

The function takes the years specified by the user has a parameter and creates a table for each year. Each table is a list with two collumns (year, month)

Usage

1

Arguments

years

a list of integers representing the years

Value

The function a data table for each year for year not present in the data, the function gives a warning message

Examples

1
2
3
4
## Not run: 
fars_read_years(2013:2015)

## End(Not run)

joaojcorreia/FarsR documentation built on Feb. 18, 2020, 12:30 a.m.