fars_summarize_years: Outputs a summary of the years and months in the data set

Description Usage Arguments Value Examples

View source: R/fars_funtions.R

Description

Based on the years provided by the user has a parameter, the funcion prints out the summary of observations grouped by years and months

Usage

1

Arguments

years

a list of integers representing the years

Value

The function a prints out a summary table of the observations grouped by year/month

Examples

1
2
3
4
## Not run: 
fars_summarize_years (2013:2015)

## End(Not run)

joaojcorreia/FarsR documentation built on Feb. 18, 2020, 12:30 a.m.