Description Usage Arguments Value Examples
View source: R/fars_funtions.R
User specifies year and state (as function parameters) and the function will plot the acidents for that given year, on a map of the state Acidents will be ploted has dots, based on their latitude and longitude
1 | fars_map_state(state.num, year)
|
state.num |
interger specifying the state |
year |
interger specifying the year of data to be ploted |
The function plots the acidents for a given year on a map of the state
1 2 3 4 | ## Not run:
fars_map_state (45,2014)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.