Description Usage Arguments Value Examples
View source: R/fars_funtions.R
Reading data from file Funtions reads data from Fatality Analysis Reporting System The function will read the defined data file into data table. If the data file is not available it will give an error message
1 | fars_read(filename)
|
filename |
string indicating the data name |
The function will read the file extablishe in the function parameter, and loads it in to a data table If file does not exist, the function will return an error message.
1 2 3 4 | ## Not run:
fars_read("accident_2013.csv.bz")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.