Description Usage Arguments Value Examples
View source: R/fars_funtions.R
The function takes the years specified by the user has a parameter and creates a table for each year. Each table is a list with two collumns (year, month)
1 | fars_read_years(years)
|
years |
a list of integers representing the years |
The function a data table for each year for year not present in the data, the function gives a warning message
1 2 3 4 | ## Not run:
fars_read_years(2013:2015)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.