Description Usage Arguments Value Examples
View source: R/fars_funtions.R
Based on the years provided by the user has a parameter, the funcion prints out the summary of observations grouped by years and months
1 | fars_summarize_years(years)
|
years |
a list of integers representing the years |
The function a prints out a summary table of the observations grouped by year/month
1 2 3 4 | ## Not run:
fars_summarize_years (2013:2015)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.